## $Id: interfaces.py 8263 2012-04-24 15:37:51Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab)
from waeup.uniben.utils.lgas import LGAS

_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.uniben')

high_qual = SimpleKofaVocabulary(
    ('National Certificate of Education','nce'),
    ('Pre Degree Programme','pre'),
    ('Diploma Programme','dip'),
    ('Ordinary National Diploma','ond'),
    ('Bachelors Degree','bd'),
    ('Masters Degree','md'),
    ('Professional Qualification','pq'),
    ('Other Certification','oc'),
    ('Higher National Diploma','hnd'),
    ('NCE AL OTH','nce_al_oth'),
    ('National Defence Academy','nda'),
    ('Awaiting Results','a_rslt'),
    ('RMC','rmc'),
    )

high_grade = SimpleKofaVocabulary(
    ('Upper Credit','upper_credit'),
    ('Distinction','distinction'),
    ('Credit','credit'),
    ('Merit','merit'),
    ('Lower Credit','lower_credit'),
    ('First Class','first_class'),
    ('Second Class Upper','second_class_upper'),
    ('Second Class Lower','second_class_lower'),
    ('Third Class','third_class'),
    ('Pass','pass'),
    ('Awaiting Results','a_rslt'),
    ('A Levels','al'),
    )

exam_types = SimpleKofaVocabulary(
    ('SSCE','ssce'),
    ('WAEC','waec'),
    ('GCE O\' LEVEL','gce_o_level'),
    ('TC II','tc_ii'),
    ('RSA','rsa'),
    ('NABTEB','nabteb'),
    ('NECO','neco'),
    ('ACE','ace'),
    ('GCE A\' LEVEL','gce_a_level'),
    ('IGCSE','igcse'),
    )


lgas_vocab = SimpleKofaVocabulary(
    *sorted([(x[1],x[0]) for x in LGAS]))

# It's recommended to replicate all fields from the base package here.
class ICustomSessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    # Base fees, do not remove.

    school_fee_base = schema.Float(
        title = _(u'School Fee (ignored)'),
        default = 0.0,
        required = False,
        )

    application_fee = schema.Float(
        title = _(u'Application Fee'),
        default = 0.0,
        required = False,
        )

    clearance_fee = schema.Float(
        title = _(u'Clearance Fee'),
        default = 0.0,
        required = False,
        )

    booking_fee = schema.Float(
        title = _(u'Booking Fee'),
        default = 0.0,
        required = False,
        )

    # Additional fees in waeup.uniben

    maint_fee = schema.Float(
        title = _(u'Maintenance Fee'),
        default = 0.0,
        required = False,
        )

    gown = schema.Float(
        title = _(u'Gown Fee'),
        default = 0.0,
        required = False,
        )

    transfer = schema.Float(
        title = _(u'Transfer Fee'),
        default = 0.0,
        required = False,
        )

    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order